##  Linking Discovered Items in Bulk
To link multiple items at once, follow these steps:
  1. Select the items that you want to link, or select the Discovery Item checkbox to select all.
Use filters to narrow down the list for selection.
For example, you can filter by an integration source and select only those items.
  2. Choose Link.


When you select the checkbox next to Discovery Item, your selection only applies to the items currently visible on the page. To select the complete list, scroll down to load all entries and select the checkbox next to Discovery Item.
